""""Program to automatically generate gatorgrader.yml files in a config directory"""

# import necessary libraries
import os

#pylint: disable=too-many-arguments
def create_gatorgrader(name, brk, fastfail, indent, version):
    """creating directory that can have files
    that can be read and written to.
    """
    # creating directory called config
    directory = "config"

    if os.path.isdir(directory) is True:
        pass
    else:
        os.mkdir(directory)

    gatorgrader_config = f"""
---
# The name of your assignment
name: {name}
# Should a check failure "break" the Gradle run?
break: {brk}
# Should a check failure immediately "break" the Gradle run?
fastfail: {fastfail}
# What level of indentation does the body of this file use?
indent: {indent}
# What version of GatorGrader should this assignment use?
version: {version}
---
"""
    with open("config/gatorgrader.yml", "w", encoding="utf8") as generate:
        generate.write(gatorgrader_config)
        generate.close()



"""This file will use all of our functions and run the program"""

import typer

# Import from configator
from configator import create_actions_config
from configator import create_gatorgradle_yml
from configator import generate_build_gradle

#pylint: disable=too-many-arguments
app = typer.Typer()
@app.command()
def main(

    name: str = typer.Option("configator-generated"),
    brk: str = typer.Option("true"),
    fastfail: str = typer.Option("false"),
    indent: int = typer.Option(2),
    version: str = typer.Option("master"),
    ggradleversion: str = typer.Option("0.5.1"),
):

    """This function will run functions to generate files"""

    # Alert user of assignment generation under specified name
    typer.echo(f"\nGenerating assignment as: {name}\n")

    # Progress bar to measure progress of necessary program functions
    try:
        with typer.progressbar(length=99) as progress:
            create_gatorgradle_yml.create_gatorgrader(name, brk, fastfail, indent, version)
            progress.update(33)
            generate_build_gradle.create_gradlebuild(ggradleversion)
            progress.update(33)
            create_actions_config.create_configator_file()
            progress.update(33)
        # Success confirmation message
        typer.secho("\nAssignment generation success!", fg = typer.colors.GREEN)
    except: # pylint: disable=bare-except
        typer.secho("\nAn error occurred in assignment generation...", fg = typer.colors.RED,
        err = True)

if __name__ == '__main__':
    app()



""""Function to generate a gradlebuild file"""

def create_gradlebuild(ggradleversion):
    """
    creating a file with gatorgradle version
    that can be read and written to
    """

#creating a variable and assigning it to strings for desired output
    gradlebuild = f'''
plugins {{
    id "org.gatored.gatorgradle" version "{ggradleversion}"
}}
'''
#creating a build.gradle file
    with open("build.gradle", "w", encoding="utf8") as generate:
        #using write function with the variable gradlebuild
        generate.write(gradlebuild)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['configator']

package_data = \
{'': ['*']}

install_requires = \
['typer>=0.4.0,<0.5.0']

entry_points = \
{'console_scripts': ['configator = configator.main:app']}

setup_kwargs = {
    'name': 'pyconfigator',
    'version': '1.0.2',
    'description': 'A Configuration File Generator for GatorGradle',
    'long_description': '# ConfiGator\n\n![Mr.ConfiGator himself](img/icon.png)\n\n[![Lint and Test](https://github.com/cmpsc-481-s22-m1/ConfiGator/actions/workflows/main.yml/badge.svg?branch=release%2F0.1.0)](https://github.com/cmpsc-481-s22-m1/ConfiGator/actions/workflows/main.yml)\n\nA configuration file generator meant to be used with [GatorGradle](https://github.com/GatorEducator/gatorgradle).\n\n## Overview\n\nConfiGator is a tool to be used in hand with GatorGradle to generate configuration\nfiles for assignments that require GatorGradle. ConfiGator uses\n[Poetry](https://python-poetry.org/) for package and dependency management.\n\n## Usage\n\n### Installing ConfiGator\n\nCommand to install ConfiGator\n\n```bash\npipx install configator\n```\n\n### Command to Change Specific Configurations\n\nThe command below will show a list of every available command to change\nspecific configurations in `config/gatorgrader.yml` or `build.gradle`.\n\n```bash\nconfigator --help\n```\n\n### If you need Assistance\n\nCreate an issue or a discussion post for assistance if you encounter any issues\nwith ConfiGator.\n\n### Contributors\n\n- [@connellyw](https://github.com/connellyw)\n- [@donizk](https://github.com/donizk)\n- [@Kevin487](https://github.com/Kevin487)\n- [@Peter-Snipes](https://github.com/Peter-Snipes)\n- [@kailaniwoodard](https://github.com/kailaniwoodard)\n- [@TheShiny1](https://github.com/TheShiny1)\n- [@mariakimheinert](https://github.com/mariakimheinert)\n- [@Michionlion](https://github.com/Michionlion)\n',
    'author': 'Kyrie Doniz',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



"""Creates pa file that will allow GatorGradle to run through GitHub Actions"""
import os

def create_configator_file():
    """Creating a file that will allow GatorGradle to run through GitHub Actions"""
    direct = ".github/workflows"

    # if directory already exists, don't create directory
    if os.path.isdir(direct) is True:
        pass
    else:
      # create directories
        os.makedirs(direct)

    data = """
name: Grade
on: [push, pull_request]
jobs:
grade:
  runs-on: ubuntu-latest
  steps:
    - name: Checkout repository
      uses: actions/checkout@v2
    - name: Run GatorGradle
      uses: GatorEducator/gatorgradle-action@v1
"""
    file = ".github/workflows/grade.yml"

    with open(file, 'w', encoding='utf-8') as create_file:
        create_file.write(data)
